@@ -63,14 +63,20 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def bytes_to_ascii(self) -> DataFormatT:
+    def list_to_bytes(self, ascii: bool = False) -> DataFormatT:
         """Convert bytes (array of bytes) to ascii
 
+        Args:
+            ascii (bool, optional): Output as ascii, by default False
+
         Returns:
             Chepy: The Chepy object.
         """
         assert isinstance(self.state, list), "Data in state is not a list"
-        self.state = bytearray(self.state).decode()
+        if ascii:
+            self.state = bytearray(self.state).decode()
+        else:
+            self.state = bytes(bytearray(self.state))
         return self
 
     @ChepyDecorators.call_stack
@@ -729,19 +735,47 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def str_to_hex(self) -> DataFormatT:
+    def str_to_hex(self, delimiter: Union[str, bytes] = b"") -> DataFormatT:
         """Converts a string to a hex string
 
+        Args:
+            delimiter (Union[str, bytes], optional): Format delimiter. Defaults to b'
+
         Returns:
             Chepy: The Chepy object.
         """
-        self.state = binascii.hexlify(self._convert_to_bytes())
+        data = self._convert_to_bytes()
+        delimiter = self._bytes_to_str(delimiter)
+        out = delimiter + delimiter.join(f"{byte:02x}" for byte in data)
+        self.state = out
         return self
 
     @ChepyDecorators.call_stack
-    def int_to_hex(self) -> DataFormatT:
+    def int_to_bytes(self, length: Union[int, None]=None, byteorder: str = 'big'):
+        """Int to bytes conversion
+
+        Args:
+            length (int, optional): Length of bytes. If not specified, byteorder is ignored and long_to_bytes is used. 
+            byteorder (str, optional): Endianness. Defaults to 'big'.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        data = self._convert_to_int()
+        if not length:
+            self.state = crypto_number.long_to_bytes(self.state)
+        else:
+            self.state = data.to_bytes(int(length), byteorder=byteorder)
+        return self
+
+    @ChepyDecorators.call_stack
+    def int_to_hex(self, unsigned_int: bool = True, bit_size: int = 64) -> DataFormatT:
         """Converts an integer into its hex equivalent
 
+        Args:
+            unsigned_int (bool, optional): Calculate the unsigned hexadecimal representation. Defaults to True
+            bit_size (int, optional): Used when unsinged_int is used
+
         Returns:
             Chepy: The Chepy object.
 
@@ -749,7 +783,11 @@ class DataFormat(ChepyCore):
             >>> Chepy(101).int_to_hex().o
             "65"
         """
-        self.state = format(self._convert_to_int(), "x")
+        i = self._convert_to_int()
+        if unsigned_int and i < 0:
+            self.state = hex((1 << bit_size) + i).strip("0x").strip("-0x")
+        else:
+            self.state = format(self._convert_to_int(), "x")
         return self
 
     @ChepyDecorators.call_stack
@@ -903,7 +941,7 @@ class DataFormat(ChepyCore):
             raise TypeError("State is not a bytearray")
 
     @ChepyDecorators.call_stack
-    def str_to_list(self) -> DataFormatT:
+    def to_list(self) -> DataFormatT:
         """Convert string to list
 
         Converts the string in state to an array of individual characyers
@@ -912,10 +950,13 @@ class DataFormat(ChepyCore):
             Chepy: The Chepy object.
 
         Examples:
-            >>> Chepy("abc").str_to_list().o
+            >>> Chepy("abc").to_list().o
             ["a", "b", "c"]
         """
-        self.state = list(self._convert_to_str())
+        if isinstance(self.state, (bytearray, bytes, str)):
+            self.state = list(self.state)
+        else:  # pragma: no cover
+            raise ValueError("State is not a valid data type")
         return self
 
     @ChepyDecorators.call_stack
@@ -1365,6 +1406,51 @@ class DataFormat(ChepyCore):
         self.state = join_by.join([d.get(p, p) for p in data])
         return self
 
+    @ChepyDecorators.call_stack
+    def swap_values(
+        self, indices1: Union[str, List[int]], indices2: Union[str, List[int]]
+    ):
+        """Swaps the values in the global bytes based on indices specified in two lists.
+
+        Args:
+            indices1 (Union[str, List[int]]): The first indices. If string, it should be , delimited
+            indices2 (Union[str, List[int]]): The second indices. If string, it should be , delimited
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        if isinstance(indices1, str):
+            indices1 = [int(x.strip()) for x in indices1.split(",")]
+        if isinstance(indices2, str):
+            indices2 = [int(x.strip()) for x in indices2.split(",")]
+
+        is_list = isinstance(self.state, list)
+        if is_list:
+            data = self.state
+        else:
+            data = bytearray(self._convert_to_bytes())
+
+        # Check if both lists are of the same length
+        if len(indices1) != len(indices2):  # pragma: no cover
+            raise ValueError("The two argument lists must have the same length.")
+
+        # Swap values in the byte list
+        for idx1, idx2 in zip(indices1, indices2):
+            # Validate indices are within bounds
+            if (
+                idx1 < 0 or idx1 >= len(data) or idx2 < 0 or idx2 >= len(data)
+            ):  # pragma: no cover
+                raise IndexError(
+                    f"Index out of range. Lenth of state is {len(data)}, indices provided {idx1} {idx2}"
+                )
+
+            # Perform the swap
+            data[idx1], data[idx2] = data[idx2], data[idx1]
+
+        # Convert the modified list back to bytes
+        self.state = data if is_list else bytes(data)
+        return self
+
     @ChepyDecorators.call_stack
     def swap_strings(self, by: int) -> DataFormatT:
         """Swap characters in string
@@ -1524,11 +1610,14 @@ class DataFormat(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def swap_endianness(self, word_length: int = 4) -> DataFormatT:
+    def swap_endianness(
+        self, word_length: int = 4, pad_incomplete: bool = True
+    ) -> DataFormatT:
         """Swap endianness.
 
         Args:
             word_length (int, optional): Word length. Use 8 for big endian. Defaults to 4.
+            pad_incomplete (bool, optional): Pad incomplete word. Defaults to True.
 
         Returns:
             Chepy: The Chepy object.
@@ -1544,6 +1633,8 @@ class DataFormat(ChepyCore):
             swapped_word = struct.unpack("<" + "B" * word_length, word)[::-1]
             swapped_data += struct.pack("B" * word_length, *swapped_word)
 
+        if not pad_incomplete:
+            swapped_data = swapped_data.replace(b"\x00", b"")
         self.state = swapped_data
         return self
 
@@ -2318,3 +2409,31 @@ class DataFormat(ChepyCore):
 
         self.state = hold
         return self
+
+    @ChepyDecorators.call_stack
+    def to_italics(self) -> DataFormatT:
+        """Convert string alphabets to italics
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        text = self._convert_to_str()
+        normal = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+        italic = "𝘢𝘣𝘤𝘥𝘦𝘧𝘨𝘩𝘪𝘫𝘬𝘭𝘮𝘯𝘰𝘱𝘲𝘳𝘴𝘵𝘶𝘷𝘸𝘹𝘺𝘻𝘈𝘉𝘊𝘋𝘌𝘍𝘎𝘏𝘐𝘑𝘒𝘓𝘔𝘕𝘖𝘗𝘘𝘙𝘚𝘛𝘜𝘝𝘞𝘟𝘠𝘡"
+        translation_table = str.maketrans(normal, italic)
+        self.state = text.translate(translation_table)
+        return self
+
+    @ChepyDecorators.call_stack
+    def from_italics(self) -> DataFormatT:
+        """Convert italic string alphabets to ascii
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        text = self._convert_to_str()
+        normal = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+        italic = "𝘢𝘣𝘤𝘥𝘦𝘧𝘨𝘩𝘪𝘫𝘬𝘭𝘮𝘯𝘰𝘱𝘲𝘳𝘴𝘵𝘶𝘷𝘸𝘹𝘺𝘻𝘈𝘉𝘊𝘋𝘌𝘍𝘎𝘏𝘐𝘑𝘒𝘓𝘔𝘕𝘖𝘗𝘘𝘙𝘚𝘛𝘜𝘝𝘞𝘟𝘠𝘡"
+        translation_table = str.maketrans(italic, normal)
+        self.state = text.translate(translation_table)
+        return self
