@@ -13,6 +13,7 @@ from .internal.ls47 import (
 )
 from .internal.constants import Ciphers, Rabbit
 from .internal.helpers import detect_delimiter
+from .internal.helpers import Zeckendorf
 
 import lazy_import
 
@@ -313,9 +314,10 @@ class EncryptionEncoding(ChepyCore):
     def xor(
         self,
         key: str,
-        key_type: Literal["hex", "utf8", "base64", "decimal"] = "hex",
+        key_type: Literal["hex", "utf8", "base64", "decimal", "raw"] = "hex",
     ) -> EncryptionEncodingT:
-        """XOR state with a key
+        """XOR state with a key. In raw format, both the state and the key is converted
+        to a bytearray.
 
         Args:
             key (str): Required. The key to xor by
@@ -330,8 +332,18 @@ class EncryptionEncoding(ChepyCore):
         """
 
         x = bytearray(b"")
+
+        if key_type == "raw":
+            _data_ba = bytearray()
+            _data = self._convert_to_str()
+            _data_ba.extend(map(ord, _data))
+            raw_key = bytearray()
+            raw_key.extend(map(ord, key))
+            for char, key_val in zip(_data_ba, itertools.cycle(raw_key)):
+                x.append(char ^ key_val)
+
         # check if state is a list and keys are list
-        if isinstance(self.state, bytearray) and isinstance(key, bytearray):
+        elif isinstance(self.state, bytearray) and isinstance(key, bytearray):
             for char, key_val in zip(self.state, itertools.cycle(key)):
                 x.append(char ^ key_val)
 
@@ -1109,7 +1121,7 @@ class EncryptionEncoding(ChepyCore):
             raise ValueError("The key must consist only of letters")  # pragma: no cover
 
         for i in range(len(input_str)):
-            if input_str[i].isalpha():
+            if input_str[i].isalpha() and input_str[i].lower() in alphabet:
                 is_upper = input_str[i].isupper()
                 input_char = input_str[i].lower()
                 key_char = key[(i - fail) % len(key)]
@@ -1151,7 +1163,7 @@ class EncryptionEncoding(ChepyCore):
             raise ValueError("The key must consist only of letters")  # pragma: no cover
 
         for i in range(len(input_str)):
-            if input_str[i].isalpha():
+            if input_str[i].isalpha() and input_str[i].lower() in alphabet:
                 is_upper = input_str[i].isupper()
                 input_char = input_str[i].lower()
                 key_char = key[(i - fail) % len(key)]
@@ -1206,7 +1218,7 @@ class EncryptionEncoding(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def atbash_encode(self) -> EncryptionEncodingT:
+    def atbash(self) -> EncryptionEncodingT:
         """Encode with Atbash cipher
 
         Returns:
@@ -1216,21 +1228,21 @@ class EncryptionEncoding(ChepyCore):
             >>> Chepy("secret").atbash_encode().o
             "HVXIVG"
         """
-        self.state = pycipher.Atbash().encipher(self._convert_to_str(), keep_punct=True)
-        return self
-
-    @ChepyDecorators.call_stack
-    def atbash_decode(self) -> EncryptionEncodingT:
-        """Decode Atbash cipher
-
-        Returns:
-            Chepy: The Chepy object.
-
-        Examples:
-            >>> Chepy("hvxivg").atbash_decode().o
-            "SECRET"
-        """
-        self.state = pycipher.Atbash().decipher(self._convert_to_str(), keep_punct=True)
+        # Reference https://github.com/jameslyons/pycipher/blob/master/pycipher/atbash.py
+        key = "ZYXWVUTSRQPONMLKJIHGFEDCBA"
+        data = self._convert_to_str()
+        ret = ""
+        arr = Ciphers.ATBASH
+        for c in data:
+            if c.isalpha():
+                if c.islower():
+                    ret += key[arr[c.upper()]].lower()
+                else:
+                    ret += key[arr[c]]
+            else:
+                ret += c
+        self.state = ret
+        # self.state = pycipher.Atbash().encipher(self._convert_to_str(), keep_punct=True)
         return self
 
     @ChepyDecorators.call_stack
@@ -1989,3 +2001,66 @@ class EncryptionEncoding(ChepyCore):
         else:
             self.state = enc.__bytes__()
         return self
+
+    @ChepyDecorators.call_stack
+    def to_zeckendorf(self, space_delim=".", byte_delim="|") -> EncryptionEncodingT:
+        """Convert the current state to a Zeckendorf representation.
+
+        Args:
+            space_delim (str, optional): Delimiter for space-separated Fibonacci numbers. Defaults to ".".
+            byte_delim (str, optional): Delimiter for byte-separated groups. Defaults to "|".
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        if isinstance(space_delim, str):
+            space_delim = space_delim.encode()
+        if isinstance(byte_delim, str):
+            byte_delim = byte_delim.encode()
+        data = self._convert_to_bytes()
+
+        encoded_parts = []
+
+        for byte_val in data:
+            if byte_val == 0:
+                # Handle zero case - we'll represent it as empty (no Fibonacci numbers)
+                encoded_parts.append("")  # pragma: no cover
+            else:
+                zeck_repr = Zeckendorf.to_zeckendorf(byte_val)
+                zeck_str = space_delim.join(str(x).encode() for x in zeck_repr)
+                encoded_parts.append(zeck_str)
+
+        self.state = byte_delim.join(encoded_parts)
+        return self
+
+    @ChepyDecorators.call_stack
+    def from_zeckendorf(self, space_delim=".", byte_delim="|") -> EncryptionEncodingT:
+        """Decode a Zeckendorf representation into bytes.
+
+        Args:
+            space_delim (str, optional): Delimiter for space-separated Fibonacci numbers. Defaults to ".".
+            byte_delim (str, optional): Delimiter for byte-separated groups. Defaults to "|".
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        if isinstance(space_delim, str):
+            space_delim = space_delim.encode()
+        if isinstance(byte_delim, str):
+            byte_delim = byte_delim.encode()
+
+        data = self._convert_to_bytes()
+        parts = data.split(byte_delim)
+        decoded_bytes = []
+
+        for part in parts:
+            if not part:  # Empty part represents 0
+                decoded_bytes.append(0)  # pragma: no cover
+            else:
+                # Sum the Fibonacci numbers
+                fib_nums = [int(s) for s in part.split(space_delim) if s]
+                byte_val = sum(fib_nums)
+                decoded_bytes.append(byte_val)
+
+        self.state = bytes(decoded_bytes)
+        return self
